pub struct ApplicationServerInfoNodeStatusData {
pub headers: Option<i32>,
pub blocks: Option<i32>,
pub verification_progress: Option<f64>,
}Expand description
ApplicationServerInfoNodeStatusData : Detailed sync status of the internal full node
Fields
headers: Option<i32>The height of the chain of header of the internal full node
blocks: Option<i32>The height of the latest validated block of the internal full node
verification_progress: Option<f64>The current synchronization progress
Implementations
Sourceimpl ApplicationServerInfoNodeStatusData
impl ApplicationServerInfoNodeStatusData
Sourcepub fn new() -> ApplicationServerInfoNodeStatusData
pub fn new() -> ApplicationServerInfoNodeStatusData
Detailed sync status of the internal full node