pub struct ApplicationServerInfoSyncStatusData {
pub crypto_code: Option<String>,
pub node_information: Option<Box<ApplicationServerInfoNodeStatusData>>,
pub chain_height: Option<i32>,
pub sync_height: Option<f32>,
pub available: Option<bool>,
}Expand description
ApplicationServerInfoSyncStatusData : Detailed sync status
Fields
crypto_code: Option<String>The CryptoCode of the crypto currency (eg. BTC)
node_information: Option<Box<ApplicationServerInfoNodeStatusData>>chain_height: Option<i32>The height of the chain of header of the internal indexer
sync_height: Option<f32>The height of the latest indexed block of the internal indexer
available: Option<bool>True if the full node and the indexer are fully synchronized
Implementations
Sourceimpl ApplicationServerInfoSyncStatusData
impl ApplicationServerInfoSyncStatusData
Sourcepub fn new() -> ApplicationServerInfoSyncStatusData
pub fn new() -> ApplicationServerInfoSyncStatusData
Detailed sync status