pub struct ApplicationUserData {
pub id: Option<String>,
pub email: Option<String>,
pub email_confirmed: Option<bool>,
pub requires_email_confirmation: Option<bool>,
pub created: Option<f32>,
pub roles: Option<Vec<String>>,
}Fields
id: Option<String>The id of the user
email: Option<String>The email of the user
email_confirmed: Option<bool>True if the email has been confirmed by the user
requires_email_confirmation: Option<bool>True if the email requires email confirmation to log in
created: Option<f32>The creation date of the user as a unix timestamp. Null if created before v1.0.5.6
roles: Option<Vec<String>>The roles of the user
Implementations
Sourceimpl ApplicationUserData
impl ApplicationUserData
pub fn new() -> ApplicationUserData