pub struct BasicAppData {
pub id: Option<String>,
pub name: Option<String>,
pub store_id: Option<String>,
pub created: Option<i32>,
pub app_type: Option<String>,
}Fields
id: Option<String>Id of the app
name: Option<String>Name given to the app when it was created
store_id: Option<String>Id of the store to which the app belongs
created: Option<i32>UNIX timestamp for when the app was created
app_type: Option<String>Type of the app which was created
Implementations
Sourceimpl BasicAppData
impl BasicAppData
pub fn new() -> BasicAppData