pub struct CreateOnChainTransactionRequest {
pub destinations: Option<Vec<CreateOnChainTransactionRequestDestination>>,
pub feerate: Option<f32>,
pub proceed_with_payjoin: Option<bool>,
pub proceed_with_broadcast: Option<bool>,
pub no_change: Option<bool>,
pub rbf: Option<bool>,
pub exclude_unconfirmed: Option<bool>,
pub selected_inputs: Option<Vec<String>>,
}Fields
destinations: Option<Vec<CreateOnChainTransactionRequestDestination>>What and where to send money
feerate: Option<f32>Transaction fee.
proceed_with_payjoin: Option<bool>Whether to attempt to do a BIP78 payjoin if one of the destinations is a BIP21 with payjoin enabled
proceed_with_broadcast: Option<bool>Whether to broadcast the transaction after creating it or to simply return the transaction in hex format.
no_change: Option<bool>Whether to send all the spent coins to the destinations (THIS CAN COST YOU SIGNIFICANT AMOUNTS OF MONEY, LEAVE FALSE UNLESS YOU KNOW WHAT YOU ARE DOING).
rbf: Option<bool>Whether to enable RBF for the transaction. Leave blank to have it random (beneficial to privacy)
exclude_unconfirmed: Option<bool>Whether to exclude unconfirmed UTXOs from the transaction.
selected_inputs: Option<Vec<String>>Restrict the creation of the transactions from the outpoints provided ONLY (coin selection)
Implementations