InvoiceMetadata

Struct InvoiceMetadata 

pub struct InvoiceMetadata {
Show 16 fields pub order_id: Option<String>, pub order_url: Option<String>, pub pos_data: Option<String>, pub buyer_name: Option<String>, pub buyer_email: Option<String>, pub buyer_country: Option<String>, pub buyer_zip: Option<String>, pub buyer_state: Option<String>, pub buyer_city: Option<String>, pub buyer_address1: Option<String>, pub buyer_address2: Option<String>, pub buyer_phone: Option<String>, pub item_desc: Option<String>, pub item_code: Option<String>, pub physical: Option<String>, pub tax_included: Option<f32>,
}
InvoiceMetadata : Additional information around the invoice that can be supplied. The mentioned properties are all optional and you can introduce any json format you wish.

Fields

order_id: Option<String>

You can use this property to store the ID of an external system. We allow you to search in the invoice list based on this ID.

order_url: Option<String>

You can use this property to store the URL to the order of an external system. This makes navigating to the order easier.

pos_data: Option<String>buyer_name: Option<String>buyer_email: Option<String>buyer_country: Option<String>buyer_zip: Option<String>buyer_state: Option<String>buyer_city: Option<String>buyer_address1: Option<String>buyer_address2: Option<String>buyer_phone: Option<String>item_desc: Option<String>item_code: Option<String>physical: Option<String>tax_included: Option<f32>

Implementations

Source

impl InvoiceMetadata

pub fn new() -> InvoiceMetadata

Additional information around the invoice that can be supplied. The mentioned properties are all optional and you can introduce any json format you wish.