pub struct InvoicePaymentMethodDataModel {Show 13 fields
pub payment_method: Option<String>,
pub crypto_code: Option<String>,
pub destination: Option<String>,
pub payment_link: Option<String>,
pub rate: Option<String>,
pub payment_method_paid: Option<String>,
pub total_paid: Option<String>,
pub due: Option<String>,
pub amount: Option<String>,
pub network_fee: Option<String>,
pub payments: Option<Vec<Payment>>,
pub activated: Option<bool>,
pub additional_data: Option<Box<InvoicePaymentMethodDataModelAdditionalData>>,
}Fields
payment_method: Option<String>Payment method available for the invoice (e.g., "BTC" or "BTC-LightningNetwork" or "BTC-LNURLPAY")
crypto_code: Option<String>Crypto code of the payment method (e.g., "BTC" or "LTC")
destination: Option<String>The destination the payment must be made to
payment_link: Option<String>A payment link that helps pay to the payment destination
rate: Option<String>The rate between this payment method’s currency and the invoice currency
payment_method_paid: Option<String>The amount paid by this payment method
total_paid: Option<String>The total amount paid by all payment methods to the invoice, converted to this payment method’s currency
due: Option<String>The total amount left to be paid, converted to this payment method’s currency (will be negative if overpaid)
amount: Option<String>The invoice amount, converted to this payment method’s currency
network_fee: Option<String>The added merchant fee to pay for network costs of this payment method.
payments: Option<Vec<Payment>>Payments made with this payment method.
activated: Option<bool>If the payment method is activated (when lazy payments option is enabled
additional_data: Option<Box<InvoicePaymentMethodDataModelAdditionalData>>Implementations