pub struct LedgerEntryData {
pub asset: Option<String>,
pub qty: Option<f32>,
pub _type: Option<String>,
}Expand description
LedgerEntryData : A single ledger entry meaning an asset and qty has changed (increased or decreased).
Fields
asset: Option<String>An asset.
qty: Option<f32>The quantity changed of the asset. Can be positive or negative.
_type: Option<String>Trade, Fee or Withdrawal
Implementations
Sourceimpl LedgerEntryData
impl LedgerEntryData
Sourcepub fn new() -> LedgerEntryData
pub fn new() -> LedgerEntryData
A single ledger entry meaning an asset and qty has changed (increased or decreased).