pub enum NetworkFeeMode {
MultiplePaymentsOnly,
Always,
Never,
}Expand description
NetworkFeeMode : Check whether network fee should be added to the invoice if on-chain payment is used. (More information) Check whether network fee should be added to the invoice if on-chain payment is used. (More information)
Variants