pub struct OnChainPaymentMethodBaseData {
pub derivation_scheme: Option<String>,
pub label: Option<String>,
pub account_key_path: Option<String>,
}Fields
derivation_scheme: Option<String>The derivation scheme
label: Option<String>A label that will be shown in the UI
account_key_path: Option<String>The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs
Implementations
Sourceimpl OnChainPaymentMethodBaseData
impl OnChainPaymentMethodBaseData
pub fn new() -> OnChainPaymentMethodBaseData