pub struct OnChainPaymentMethodData {
pub enabled: Option<bool>,
pub payment_method: Option<String>,
pub derivation_scheme: Option<String>,
pub label: Option<String>,
pub account_key_path: Option<String>,
pub crypto_code: Option<String>,
}Fields
enabled: Option<bool>Whether the payment method is enabled
payment_method: Option<String>The payment method
derivation_scheme: Option<String>The derivation scheme
label: Option<String>A label that will be shown in the UI
account_key_path: Option<String>The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs
crypto_code: Option<String>Crypto code of the payment method
Implementations
Sourceimpl OnChainPaymentMethodData
impl OnChainPaymentMethodData
pub fn new() -> OnChainPaymentMethodData