pub struct PaymentRequestData {Show 13 fields
pub amount: Option<String>,
pub title: Option<String>,
pub currency: Option<String>,
pub email: Option<String>,
pub description: Option<String>,
pub expiry_date: Option<f32>,
pub embedded_css: Option<String>,
pub custom_css_link: Option<String>,
pub allow_custom_payment_amounts: Option<bool>,
pub id: Option<String>,
pub store_id: Option<String>,
pub status: Option<Status>,
pub created_time: Option<f32>,
}Fields
amount: Option<String>The amount of the payment request
title: Option<String>The title of the payment request
currency: Option<String>The currency of the payment request. If empty, the store’s default currency code will be used.
email: Option<String>The email used in invoices generated by the payment request
description: Option<String>The description of the payment request
expiry_date: Option<f32>The expiry date of the payment request
embedded_css: Option<String>Custom CSS styling for the payment request
custom_css_link: Option<String>Custom CSS link for styling the payment request
allow_custom_payment_amounts: Option<bool>Whether to allow users to create invoices that partially pay the payment request
id: Option<String>The id of the payment request
store_id: Option<String>The store identifier that the payment request belongs to
status: Option<Status>The status of the payment request
created_time: Option<f32>The creation date of the payment request
Implementations
Sourceimpl PaymentRequestData
impl PaymentRequestData
pub fn new() -> PaymentRequestData