pub struct ProblemDetails {
pub code: Option<String>,
pub message: Option<String>,
}Expand description
ProblemDetails : Description of an error happening during processing of the request
Fields
code: Option<String>An error code describing the error
message: Option<String>User friendly error message about the error
Implementations
Sourceimpl ProblemDetails
impl ProblemDetails
Sourcepub fn new() -> ProblemDetails
pub fn new() -> ProblemDetails
Description of an error happening during processing of the request