pub struct PullPaymentData {
pub id: Option<String>,
pub name: Option<String>,
pub description: Option<String>,
pub currency: Option<String>,
pub amount: Option<String>,
pub period: Option<i32>,
pub bolt11_expiration: Option<String>,
pub auto_approve_claims: Option<bool>,
pub archived: Option<bool>,
pub view_link: Option<String>,
}Fields
id: Option<String>Id of the pull payment
name: Option<String>Name given to pull payment when it was created
description: Option<String>Description given to pull payment when it was created
currency: Option<String>The currency of the pull payment’s amount
amount: Option<String>The amount in the currency of this pull payment as a decimal string
period: Option<i32>The length of each period in seconds
bolt11_expiration: Option<String>If lightning is activated, do not accept BOLT11 invoices with expiration less than … days
auto_approve_claims: Option<bool>Any payouts created for this pull payment will skip the approval phase upon creation
archived: Option<bool>Whether this pull payment is archived
view_link: Option<String>The link to a page to claim payouts to this pull payment
Implementations
Sourceimpl PullPaymentData
impl PullPaymentData
pub fn new() -> PullPaymentData