pub struct PullPaymentsCreatePullPaymentRequest {
pub name: Option<String>,
pub description: Option<String>,
pub amount: Option<String>,
pub currency: Option<String>,
pub period: Option<i32>,
pub bolt11_expiration: Option<String>,
pub auto_approve_claims: Option<bool>,
pub starts_at: Option<i32>,
pub expires_at: Option<i32>,
pub payment_methods: Option<Vec<String>>,
}Fields
name: Option<String>The name of the pull payment
description: Option<String>The description of the pull payment
amount: Option<String>The amount in currency of this pull payment as a decimal string
currency: Option<String>The currency of the amount.
period: Option<i32>The length of each period in seconds.
bolt11_expiration: Option<String>If lightning is activated, do not accept BOLT11 invoices with expiration less than … days
auto_approve_claims: Option<bool>Any payouts created for this pull payment will skip the approval phase upon creation
starts_at: Option<i32>When this pull payment is effective. Already started if null or unspecified.
expires_at: Option<i32>When this pull payment expires. Never expires if null or unspecified.
payment_methods: Option<Vec<String>>The list of supported payment methods supported by this pull payment. Available options can be queried from the StorePaymentMethods_GetStorePaymentMethods endpoint
Implementations