StoreData

Struct StoreData 

pub struct StoreData {
Show 26 fields pub name: Option<String>, pub website: Option<String>, pub default_currency: Option<String>, pub invoice_expiration: Option<Box<TimeSpanSeconds>>, pub monitoring_expiration: Option<Box<TimeSpanSeconds>>, pub speed_policy: Option<SpeedPolicy>, pub lightning_description_template: Option<String>, pub payment_tolerance: Option<f64>, pub anyone_can_create_invoice: Option<bool>, pub requires_refund_email: Option<bool>, pub receipt: Option<Box<ReceiptOptions>>, pub lightning_amount_in_satoshi: Option<bool>, pub lightning_private_route_hints: Option<bool>, pub on_chain_with_ln_invoice_fallback: Option<bool>, pub redirect_automatically: Option<bool>, pub show_recommended_fee: Option<bool>, pub recommended_fee_block_target: Option<i32>, pub default_lang: Option<String>, pub custom_logo: Option<String>, pub custom_css: Option<String>, pub html_title: Option<String>, pub network_fee_mode: Option<NetworkFeeMode>, pub pay_join_enabled: Option<bool>, pub lazy_payment_methods: Option<bool>, pub default_payment_method: Option<String>, pub id: Option<String>,
}

Fields

name: Option<String>

The name of the store

website: Option<String>

The absolute url of the store

default_currency: Option<String>

The default currency of the store

invoice_expiration: Option<Box<TimeSpanSeconds>>

The time after which an invoice is considered expired if not paid. The value will be rounded down to a minute.

monitoring_expiration: Option<Box<TimeSpanSeconds>>

The time after which an invoice which has been paid but not confirmed will be considered invalid. The value will be rounded down to a minute.

speed_policy: Option<SpeedPolicy>lightning_description_template: Option<String>

The BOLT11 description of the lightning invoice in the checkout. You can use placeholders ‘{StoreName}’, ‘{ItemDescription}’ and ‘{OrderId}’.

payment_tolerance: Option<f64>

Consider an invoice fully paid, even if the payment is missing ‘x’ % of the full amount.

anyone_can_create_invoice: Option<bool>

If true, then no authentication is needed to create invoices on this store.

requires_refund_email: Option<bool>

If true, the checkout page will ask to enter an email address before accessing payment information.

receipt: Option<Box<ReceiptOptions>>lightning_amount_in_satoshi: Option<bool>

If true, lightning payment methods show amount in satoshi in the checkout page.

lightning_private_route_hints: Option<bool>

Should private route hints be included in the lightning payment of the checkout page.

on_chain_with_ln_invoice_fallback: Option<bool>

Include lightning invoice fallback to on-chain BIP21 payment url.

redirect_automatically: Option<bool>

After successfull payment, should the checkout page redirect the user automatically to the redirect URL of the invoice?

show_recommended_fee: Option<bool>recommended_fee_block_target: Option<i32>

The fee rate recommendation in the checkout page for the on-chain payment to be confirmed after ‘x’ blocks.

default_lang: Option<String>

The default language to use in the checkout page. (The different translations available are listed here

URL to a logo to include in the checkout page.

custom_css: Option<String>

URL to a CSS stylesheet to include in the checkout page

html_title: Option<String>

The HTML title of the checkout page (when you over the tab in your browser)

network_fee_mode: Option<NetworkFeeMode>pay_join_enabled: Option<bool>

If true, payjoin will be proposed in the checkout page if possible. (More information)

lazy_payment_methods: Option<bool>

If true, payment methods are enabled individually upon user interaction in the invoice

default_payment_method: Option<String>

The default payment method to load when displaying an invoice. It can be in the format of BTC_LightningNetwork to specify Lightning to be the default or BTC_OnChain/ BTC for on-chain to be the default.

id: Option<String>

The id of the store

Implementations