pub struct UpdateOnChainPaymentMethodRequest {
pub enabled: Option<bool>,
pub derivation_scheme: Option<String>,
pub label: Option<String>,
pub account_key_path: Option<String>,
}Fields
enabled: Option<bool>Whether the payment method is enabled
derivation_scheme: Option<String>The derivation scheme
label: Option<String>A label that will be shown in the UI
account_key_path: Option<String>The wallet fingerprint followed by the keypath to derive the account key used for signing operation or creating PSBTs
Implementations