pub struct WebhookDataBaseAuthorizedEvents {
pub everything: Option<bool>,
pub specific_events: Option<Vec<String>>,
}Expand description
WebhookDataBaseAuthorizedEvents : Which event should be received by this endpoint
Fields
everything: Option<bool>If true, the endpoint will receive all events related to the store.
specific_events: Option<Vec<String>>If everything is false, the specific events that the endpoint is interested in. Current events are: InvoiceCreated, InvoiceReceivedPayment, InvoiceProcessing, InvoiceExpired, InvoiceSettled, InvoiceInvalid.
Implementations
Sourceimpl WebhookDataBaseAuthorizedEvents
impl WebhookDataBaseAuthorizedEvents
Sourcepub fn new() -> WebhookDataBaseAuthorizedEvents
pub fn new() -> WebhookDataBaseAuthorizedEvents
Which event should be received by this endpoint