pub struct WebhookDataCreate {
pub id: Option<String>,
pub enabled: Option<bool>,
pub automatic_redelivery: Option<bool>,
pub url: Option<String>,
pub authorized_events: Option<Box<WebhookDataBaseAuthorizedEvents>>,
pub secret: Option<String>,
}Fields
id: Option<String>The id of the webhook
enabled: Option<bool>Whether this webhook is enabled or not
automatic_redelivery: Option<bool>If true, BTCPay Server will retry to redeliver any failed delivery after 10 seconds, 1 minutes and up to 6 times after 10 minutes.
url: Option<String>The endpoint where BTCPay Server will make the POST request with the webhook body
secret: Option<String>Must be used by the callback receiver to ensure the delivery comes from BTCPay Server. BTCPay Server includes the BTCPay-Sig HTTP header, whose format is sha256=HMAC256(UTF8(webhook's secret), body). The pattern to authenticate the webhook is similar to how to secure webhooks in Github.
Implementations
Sourceimpl WebhookDataCreate
impl WebhookDataCreate
pub fn new() -> WebhookDataCreate