pub struct WebhookDataCreateAllOf {
pub secret: Option<String>,
}Fields
secret: Option<String>Must be used by the callback receiver to ensure the delivery comes from BTCPay Server. BTCPay Server includes the BTCPay-Sig HTTP header, whose format is sha256=HMAC256(UTF8(webhook's secret), body). The pattern to authenticate the webhook is similar to how to secure webhooks in Github.
Implementations
Sourceimpl WebhookDataCreateAllOf
impl WebhookDataCreateAllOf
pub fn new() -> WebhookDataCreateAllOf