pub struct WebhookInvoiceInvalidEvent {
pub delivery_id: Option<String>,
pub webhook_id: Option<String>,
pub original_delivery_id: Option<String>,
pub is_redelivery: Option<bool>,
pub _type: Option<String>,
pub timestamp: Option<f32>,
pub store_id: Option<String>,
pub invoice_id: Option<String>,
pub manually_marked: Option<bool>,
}Expand description
WebhookInvoiceInvalidEvent : Callback sent if the type is InvoiceInvalid
Fields
delivery_id: Option<String>The delivery id of the webhook
webhook_id: Option<String>The id of the webhook
original_delivery_id: Option<String>If this delivery is a redelivery, the is the delivery id of the original delivery.
is_redelivery: Option<bool>True if this delivery is a redelivery
_type: Option<String>The type of this event, current available are InvoiceCreated, InvoiceReceivedPayment, InvoiceProcessing, InvoiceExpired, InvoiceSettled, InvoiceInvalid, and InvoicePaymentSettled.
timestamp: Option<f32>The timestamp when this delivery has been created
store_id: Option<String>The store id of the invoice’s event
invoice_id: Option<String>The invoice id of the invoice’s event
manually_marked: Option<bool>Whether the invoice have been manually marked as confirmed. If false, this invoice has received payments which could not confirm in time.
Implementations
Sourceimpl WebhookInvoiceInvalidEvent
impl WebhookInvoiceInvalidEvent
Sourcepub fn new() -> WebhookInvoiceInvalidEvent
pub fn new() -> WebhookInvoiceInvalidEvent
Callback sent if the type is InvoiceInvalid