pub struct WebhookInvoiceProcessingEvent {
pub delivery_id: Option<String>,
pub webhook_id: Option<String>,
pub original_delivery_id: Option<String>,
pub is_redelivery: Option<bool>,
pub _type: Option<String>,
pub timestamp: Option<f32>,
pub store_id: Option<String>,
pub invoice_id: Option<String>,
pub over_paid: Option<bool>,
}Expand description
WebhookInvoiceProcessingEvent : Callback sent if the type is InvoiceProcessing
Fields
delivery_id: Option<String>The delivery id of the webhook
webhook_id: Option<String>The id of the webhook
original_delivery_id: Option<String>If this delivery is a redelivery, the is the delivery id of the original delivery.
is_redelivery: Option<bool>True if this delivery is a redelivery
_type: Option<String>The type of this event, current available are InvoiceCreated, InvoiceReceivedPayment, InvoiceProcessing, InvoiceExpired, InvoiceSettled, InvoiceInvalid, and InvoicePaymentSettled.
timestamp: Option<f32>The timestamp when this delivery has been created
store_id: Option<String>The store id of the invoice’s event
invoice_id: Option<String>The invoice id of the invoice’s event
over_paid: Option<bool>Whether this invoice has received more money than expected
Implementations
Sourceimpl WebhookInvoiceProcessingEvent
impl WebhookInvoiceProcessingEvent
Sourcepub fn new() -> WebhookInvoiceProcessingEvent
pub fn new() -> WebhookInvoiceProcessingEvent
Callback sent if the type is InvoiceProcessing