CreateLightningInvoiceRequest

Struct CreateLightningInvoiceRequest 

pub struct CreateLightningInvoiceRequest {
    pub amount: Option<String>,
    pub description: Option<String>,
    pub description_hash: Option<String>,
    pub expiry: Option<Box<TimeSpanSeconds>>,
    pub private_route_hints: Option<bool>,
}

Fields

amount: Option<String>

Amount wrapped in a string, represented in a millistatoshi string. (1000 millisatoshi = 1 satoshi)

description: Option<String>

Description of the invoice in the BOLT11

description_hash: Option<String>

Description hash of the invoice in the BOLT11

expiry: Option<Box<TimeSpanSeconds>>

Expiration time in seconds

private_route_hints: Option<bool>

True if the invoice should include private route hints

Implementations